#Configuration

## Paramètres d'exécution

- `host`
- `port`
- `workers`

## Variables d'environnement

- `VYRO_ENV`
- `VYRO_SECRET_KEY`
- `VYRO_WORKERS`
-`VYRO_LOG_SAMPLE_INFO`
- `VYRO_LOG_SAMPLE_WARN`
- `VYRO_LOG_SAMPLE_ERROR`

Utilisez `vyro doctor --strict` dans CI pour les contrôles de préparation à la production.